==> jc-1.4.0.tar.gz: soot/dava/toolkits/base/misc/ThrowNullConverter.h <==
// public class soot.dava.toolkits.base.misc.ThrowNullConverter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e45ba6bccc27fb96 soot_dava_toolkits_base_misc_ThrowNullConverter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_misc_ThrowNullConverter_H_
#define _JC_soot_dava_toolkits_base_misc_ThrowNullConverter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_RefType$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_dava_DavaBody$object;
struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$sub_refs	_jc_soot_dava_toolkits_base_misc_ThrowNullConverter$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$sub_nonrefs	_jc_soot_dava_toolkits_base_misc_ThrowNullConverter$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$refs	_jc_soot_dava_toolkits_base_misc_ThrowNullConverter$refs;
typedef struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$nonrefs	_jc_soot_dava_toolkits_base_misc_ThrowNullConverter$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$object	_jc_soot_dava_toolkits_base_misc_ThrowNullConverter$object;

typedef const struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$vmethods	_jc_soot_dava_toolkits_base_misc_ThrowNullConverter$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$vtable	_jc_soot_dava_toolkits_base_misc_ThrowNullConverter$vtable;
typedef const struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$vtype	_jc_soot_dava_toolkits_base_misc_ThrowNullConverter$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$method$convert$79338b70c5bb1713(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$object *, struct _jc_soot_dava_DavaBody$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$method_info$convert$79338b70c5bb1713;

// Static methods
extern struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$object *_jc_soot_dava_toolkits_base_misc_ThrowNullConverter$method$v$92b6008996cf6574(_jc_env *);

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$vmethods {
	void	(*convert$79338b70c5bb1713)(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$object *, struct _jc_soot_dava_DavaBody$object *);
};

// Vtable
struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_misc_ThrowNullConverter$vmethods	soot_dava_toolkits_base_misc_ThrowNullConverter;
};

// Vtype
struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_misc_ThrowNullConverter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$sub_refs {
	struct _jc_soot_RefType$object	*npeRef;
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$refs {
    _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$sub_refs	soot_dava_toolkits_base_misc_ThrowNullConverter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$sub_nonrefs	soot_dava_toolkits_base_misc_ThrowNullConverter;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$object {
	_jc_soot_dava_toolkits_base_misc_ThrowNullConverter$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_misc_ThrowNullConverter$vtype	*vtype;
	_jc_soot_dava_toolkits_base_misc_ThrowNullConverter$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$vtype _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_misc_ThrowNullConverter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$class_object;

#endif	/* _JC_soot_dava_toolkits_base_misc_ThrowNullConverter_H_ */

==> jc-1.4.6.tar.gz: soot/dava/toolkits/base/misc/ThrowNullConverter.h <==
// public class soot.dava.toolkits.base.misc.ThrowNullConverter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e45ba6bccc27fb96 soot_dava_toolkits_base_misc_ThrowNullConverter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_misc_ThrowNullConverter_H_
#define _JC_soot_dava_toolkits_base_misc_ThrowNullConverter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_RefType$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_dava_DavaBody$object;
struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$sub_refs	_jc_soot_dava_toolkits_base_misc_ThrowNullConverter$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$sub_nonrefs	_jc_soot_dava_toolkits_base_misc_ThrowNullConverter$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$refs	_jc_soot_dava_toolkits_base_misc_ThrowNullConverter$refs;
typedef struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$nonrefs	_jc_soot_dava_toolkits_base_misc_ThrowNullConverter$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$object	_jc_soot_dava_toolkits_base_misc_ThrowNullConverter$object;

typedef const struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$vmethods	_jc_soot_dava_toolkits_base_misc_ThrowNullConverter$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$vtable	_jc_soot_dava_toolkits_base_misc_ThrowNullConverter$vtable;
typedef const struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$vtype	_jc_soot_dava_toolkits_base_misc_ThrowNullConverter$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$method$convert$79338b70c5bb1713(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$object *, struct _jc_soot_dava_DavaBody$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$method_info$convert$79338b70c5bb1713;

// Static methods
extern struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$object *_jc_soot_dava_toolkits_base_misc_ThrowNullConverter$method$v$92b6008996cf6574(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$vmethods {
	void	(*convert$79338b70c5bb1713)(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$object *, struct _jc_soot_dava_DavaBody$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_misc_ThrowNullConverter$vmethods	soot_dava_toolkits_base_misc_ThrowNullConverter;
};

// Vtype
struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_misc_ThrowNullConverter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$sub_refs {
	struct _jc_soot_RefType$object	*npeRef;
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$refs {
    _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$sub_refs	soot_dava_toolkits_base_misc_ThrowNullConverter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$sub_nonrefs	soot_dava_toolkits_base_misc_ThrowNullConverter;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$object {
	_jc_soot_dava_toolkits_base_misc_ThrowNullConverter$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_misc_ThrowNullConverter$vtype	*vtype;
	_jc_soot_dava_toolkits_base_misc_ThrowNullConverter$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$vtype _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_misc_ThrowNullConverter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_misc_ThrowNullConverter$class_object;

#endif	/* _JC_soot_dava_toolkits_base_misc_ThrowNullConverter_H_ */
